# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/instancegroup/instance_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1.instancegroup import instance_group_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/instancegroup/instance_group_service.proto',
  package='yandex.cloud.compute.v1.instancegroup',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.compute.v1.instancegroupZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1/instancegroup;instancegroup',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nByandex/cloud/compute/v1/instancegroup/instance_group_service.proto\x12%yandex.cloud.compute.v1.instancegroup\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a:yandex/cloud/compute/v1/instancegroup/instance_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\x8a\x01\n\x17GetInstanceGroupRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x46\n\x04view\x18\x02 \x01(\x0e\x32\x38.yandex.cloud.compute.v1.instancegroup.InstanceGroupView\"\xca\x08\n\x1a\x43reateInstanceGroupRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\xa6\x01\n\x06labels\x18\x05 \x03(\x0b\x32M.yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12X\n\x11instance_template\x18\x06 \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.InstanceTemplateB\x04\xe8\xc7\x31\x01\x12N\n\x0cscale_policy\x18\x07 \x01(\x0b\x32\x32.yandex.cloud.compute.v1.instancegroup.ScalePolicyB\x04\xe8\xc7\x31\x01\x12P\n\rdeploy_policy\x18\x08 \x01(\x0b\x32\x33.yandex.cloud.compute.v1.instancegroup.DeployPolicyB\x04\xe8\xc7\x31\x01\x12X\n\x11\x61llocation_policy\x18\t \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.AllocationPolicyB\x04\xe8\xc7\x31\x01\x12S\n\x12load_balancer_spec\x18\n \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.LoadBalancerSpec\x12S\n\x12health_checks_spec\x18\x0b \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.HealthChecksSpec\x12\x1a\n\x12service_account_id\x18\x0c \x01(\t\x12\x42\n\tvariables\x18\r \x03(\x0b\x32/.yandex.cloud.compute.v1.instancegroup.Variable\x12\x1b\n\x13\x64\x65letion_protection\x18\x0e \x01(\x08\x12j\n\x1e\x61pplication_load_balancer_spec\x18\x0f \x01(\x0b\x32\x42.yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"m\n\"CreateInstanceGroupFromYamlRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x13instance_group_yaml\x18\x02 \x01(\tB\x11\xe8\xc7\x31\x01\x8a\xc8\x31\t<=1048576\"B\n\x1b\x43reateInstanceGroupMetadata\x12#\n\x11instance_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\x9f\x08\n\x1aUpdateInstanceGroupRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\xa6\x01\n\x06labels\x18\x05 \x03(\x0b\x32M.yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12X\n\x11instance_template\x18\x06 \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.InstanceTemplateB\x04\xe8\xc7\x31\x01\x12N\n\x0cscale_policy\x18\x07 \x01(\x0b\x32\x32.yandex.cloud.compute.v1.instancegroup.ScalePolicyB\x04\xe8\xc7\x31\x01\x12P\n\rdeploy_policy\x18\x08 \x01(\x0b\x32\x33.yandex.cloud.compute.v1.instancegroup.DeployPolicyB\x04\xe8\xc7\x31\x01\x12X\n\x11\x61llocation_policy\x18\t \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.AllocationPolicyB\x04\xe8\xc7\x31\x01\x12S\n\x12health_checks_spec\x18\x0b \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.HealthChecksSpec\x12\x1a\n\x12service_account_id\x18\x0c \x01(\t\x12S\n\x12load_balancer_spec\x18\x0e \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.LoadBalancerSpec\x12\x42\n\tvariables\x18\x0f \x03(\x0b\x32/.yandex.cloud.compute.v1.instancegroup.Variable\x12\x1b\n\x13\x64\x65letion_protection\x18\x10 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"}\n\"UpdateInstanceGroupFromYamlRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x13instance_group_yaml\x18\x02 \x01(\tB\x11\xe8\xc7\x31\x01\x8a\xc8\x31\t<=1048576\"8\n\x1bUpdateInstanceGroupMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"D\n\x19StartInstanceGroupRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"7\n\x1aStartInstanceGroupMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"C\n\x18StopInstanceGroupRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n\x19StopInstanceGroupMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"E\n\x1a\x44\x65leteInstanceGroupRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"8\n\x1b\x44\x65leteInstanceGroupMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"4\n\x17\x44\x65leteInstancesMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"2\n\x15StopInstancesMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"\xd6\x01\n\x19ListInstanceGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x46\n\x04view\x18\x05 \x01(\x0e\x32\x38.yandex.cloud.compute.v1.instancegroup.InstanceGroupView\"\x84\x01\n\x1aListInstanceGroupsResponse\x12M\n\x0finstance_groups\x18\x01 \x03(\x0b\x32\x34.yandex.cloud.compute.v1.instancegroup.InstanceGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa6\x01\n!ListInstanceGroupInstancesRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x88\x01\n\"ListInstanceGroupInstancesResponse\x12I\n\tinstances\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.ManagedInstance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x88\x01\n\x16\x44\x65leteInstancesRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12-\n\x14managed_instance_ids\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x03>=1\x8a\xc8\x31\x04<=50\x12\x16\n\x0e\x63reate_another\x18\x03 \x01(\x08\"n\n\x14StopInstancesRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12-\n\x14managed_instance_ids\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x03>=1\x8a\xc8\x31\x04<=50\"\xa7\x01\n\"ListInstanceGroupOperationsRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"u\n#ListInstanceGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9f\x01\n\"ListInstanceGroupLogRecordsRequest\x12\x1f\n\x11instance_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x85\x01\n#ListInstanceGroupLogRecordsResponse\x12\x45\n\x0blog_records\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.compute.v1.instancegroup.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*(\n\x11InstanceGroupView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x32\xa7\x1c\n\x14InstanceGroupService\x12\xb3\x01\n\x03Get\x12>.yandex.cloud.compute.v1.instancegroup.GetInstanceGroupRequest\x1a\x34.yandex.cloud.compute.v1.instancegroup.InstanceGroup\"6\x82\xd3\xe4\x93\x02\x30\x12./compute/v1/instanceGroups/{instance_group_id}\x12\xaf\x01\n\x04List\x12@.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsRequest\x1a\x41.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/compute/v1/instanceGroups\x12\xc5\x01\n\x06\x43reate\x12\x41.yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest\x1a!.yandex.cloud.operation.Operation\"U\x82\xd3\xe4\x93\x02\x1f\"\x1a/compute/v1/instanceGroups:\x01*\xb2\xd2*,\n\x1b\x43reateInstanceGroupMetadata\x12\rInstanceGroup\x12\xda\x01\n\x0e\x43reateFromYaml\x12I.yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupFromYamlRequest\x1a!.yandex.cloud.operation.Operation\"Z\x82\xd3\xe4\x93\x02$\"\x1f/compute/v1/instanceGroups:yaml:\x01*\xb2\xd2*,\n\x1b\x43reateInstanceGroupMetadata\x12\rInstanceGroup\x12\xd9\x01\n\x06Update\x12\x41.yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest\x1a!.yandex.cloud.operation.Operation\"i\x82\xd3\xe4\x93\x02\x33\x32./compute/v1/instanceGroups/{instance_group_id}:\x01*\xb2\xd2*,\n\x1bUpdateInstanceGroupMetadata\x12\rInstanceGroup\x12\xee\x01\n\x0eUpdateFromYaml\x12I.yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupFromYamlRequest\x1a!.yandex.cloud.operation.Operation\"n\x82\xd3\xe4\x93\x02\x38\x32\x33/compute/v1/instanceGroups/{instance_group_id}:yaml:\x01*\xb2\xd2*,\n\x1bUpdateInstanceGroupMetadata\x12\rInstanceGroup\x12\xd5\x01\n\x04Stop\x12?.yandex.cloud.compute.v1.instancegroup.StopInstanceGroupRequest\x1a!.yandex.cloud.operation.Operation\"i\x82\xd3\xe4\x93\x02\x35\"3/compute/v1/instanceGroups/{instance_group_id}:stop\xb2\xd2**\n\x19StopInstanceGroupMetadata\x12\rInstanceGroup\x12\xd9\x01\n\x05Start\x12@.yandex.cloud.compute.v1.instancegroup.StartInstanceGroupRequest\x1a!.yandex.cloud.operation.Operation\"k\x82\xd3\xe4\x93\x02\x36\"4/compute/v1/instanceGroups/{instance_group_id}:start\xb2\xd2*+\n\x1aStartInstanceGroupMetadata\x12\rInstanceGroup\x12\xde\x01\n\x06\x44\x65lete\x12\x41.yandex.cloud.compute.v1.instancegroup.DeleteInstanceGroupRequest\x1a!.yandex.cloud.operation.Operation\"n\x82\xd3\xe4\x93\x02\x30*./compute/v1/instanceGroups/{instance_group_id}\xb2\xd2*4\n\x1b\x44\x65leteInstanceGroupMetadata\x12\x15google.protobuf.Empty\x12\xe6\x01\n\rListInstances\x12H.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesRequest\x1aI.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/compute/v1/instanceGroups/{instance_group_id}/instances\x12\xa1\x01\n\x0f\x44\x65leteInstances\x12=.yandex.cloud.compute.v1.instancegroup.DeleteInstancesRequest\x1a!.yandex.cloud.operation.Operation\",\xb2\xd2*(\n\x17\x44\x65leteInstancesMetadata\x12\rInstanceGroup\x12\x9b\x01\n\rStopInstances\x12;.yandex.cloud.compute.v1.instancegroup.StopInstancesRequest\x1a!.yandex.cloud.operation.Operation\"*\xb2\xd2*&\n\x15StopInstancesMetadata\x12\rInstanceGroup\x12\xea\x01\n\x0eListOperations\x12I.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsRequest\x1aJ.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/compute/v1/instanceGroups/{instance_group_id}/operations\x12\xe4\x01\n\x0eListLogRecords\x12I.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsRequest\x1aJ.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/compute/v1/instanceGroups/{instance_group_id}:logs\x12\xba\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/compute/v1/instanceGroups/{resource_id}:listAccessBindings\x12\xea\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\x82\xd3\xe4\x93\x02?\":/compute/v1/instanceGroups/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xf6\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\x82\xd3\xe4\x93\x02\x42\"=/compute/v1/instanceGroups/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyB\x84\x01\n)yandex.cloud.api.compute.v1.instancegroupZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1/instancegroup;instancegroupb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_INSTANCEGROUPVIEW = _descriptor.EnumDescriptor(
  name='InstanceGroupView',
  full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupView',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5021,
  serialized_end=5061,
)
_sym_db.RegisterEnumDescriptor(_INSTANCEGROUPVIEW)

InstanceGroupView = enum_type_wrapper.EnumTypeWrapper(_INSTANCEGROUPVIEW)
BASIC = 0
FULL = 1



_GETINSTANCEGROUPREQUEST = _descriptor.Descriptor(
  name='GetInstanceGroupRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.GetInstanceGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.GetInstanceGroupRequest.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view', full_name='yandex.cloud.compute.v1.instancegroup.GetInstanceGroupRequest.view', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=511,
)


_CREATEINSTANCEGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1612,
)

_CREATEINSTANCEGROUPREQUEST = _descriptor.Descriptor(
  name='CreateInstanceGroupRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.name', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.description', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.labels', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_template', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.instance_template', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_policy', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.scale_policy', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_policy', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.deploy_policy', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocation_policy', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.allocation_policy', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_balancer_spec', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.load_balancer_spec', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_checks_spec', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.health_checks_spec', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.service_account_id', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.variables', index=11,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.deletion_protection', index=12,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_load_balancer_spec', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.application_load_balancer_spec', index=13,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEINSTANCEGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=514,
  serialized_end=1612,
)


_CREATEINSTANCEGROUPFROMYAMLREQUEST = _descriptor.Descriptor(
  name='CreateInstanceGroupFromYamlRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupFromYamlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupFromYamlRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_group_yaml', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupFromYamlRequest.instance_group_yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\t<=1048576', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1614,
  serialized_end=1723,
)


_CREATEINSTANCEGROUPMETADATA = _descriptor.Descriptor(
  name='CreateInstanceGroupMetadata',
  full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupMetadata.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1725,
  serialized_end=1791,
)


_UPDATEINSTANCEGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1612,
)

_UPDATEINSTANCEGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateInstanceGroupRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_template', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.instance_template', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale_policy', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.scale_policy', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_policy', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.deploy_policy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocation_policy', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.allocation_policy', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_checks_spec', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.health_checks_spec', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.service_account_id', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_balancer_spec', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.load_balancer_spec', index=11,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.variables', index=12,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.deletion_protection', index=13,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEINSTANCEGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1794,
  serialized_end=2849,
)


_UPDATEINSTANCEGROUPFROMYAMLREQUEST = _descriptor.Descriptor(
  name='UpdateInstanceGroupFromYamlRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupFromYamlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupFromYamlRequest.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_group_yaml', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupFromYamlRequest.instance_group_yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\t<=1048576', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2851,
  serialized_end=2976,
)


_UPDATEINSTANCEGROUPMETADATA = _descriptor.Descriptor(
  name='UpdateInstanceGroupMetadata',
  full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupMetadata.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2978,
  serialized_end=3034,
)


_STARTINSTANCEGROUPREQUEST = _descriptor.Descriptor(
  name='StartInstanceGroupRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.StartInstanceGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.StartInstanceGroupRequest.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3036,
  serialized_end=3104,
)


_STARTINSTANCEGROUPMETADATA = _descriptor.Descriptor(
  name='StartInstanceGroupMetadata',
  full_name='yandex.cloud.compute.v1.instancegroup.StartInstanceGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.StartInstanceGroupMetadata.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3106,
  serialized_end=3161,
)


_STOPINSTANCEGROUPREQUEST = _descriptor.Descriptor(
  name='StopInstanceGroupRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.StopInstanceGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.StopInstanceGroupRequest.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3163,
  serialized_end=3230,
)


_STOPINSTANCEGROUPMETADATA = _descriptor.Descriptor(
  name='StopInstanceGroupMetadata',
  full_name='yandex.cloud.compute.v1.instancegroup.StopInstanceGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.StopInstanceGroupMetadata.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3232,
  serialized_end=3286,
)


_DELETEINSTANCEGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteInstanceGroupRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.DeleteInstanceGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.DeleteInstanceGroupRequest.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3288,
  serialized_end=3357,
)


_DELETEINSTANCEGROUPMETADATA = _descriptor.Descriptor(
  name='DeleteInstanceGroupMetadata',
  full_name='yandex.cloud.compute.v1.instancegroup.DeleteInstanceGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.DeleteInstanceGroupMetadata.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3359,
  serialized_end=3415,
)


_DELETEINSTANCESMETADATA = _descriptor.Descriptor(
  name='DeleteInstancesMetadata',
  full_name='yandex.cloud.compute.v1.instancegroup.DeleteInstancesMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.DeleteInstancesMetadata.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3417,
  serialized_end=3469,
)


_STOPINSTANCESMETADATA = _descriptor.Descriptor(
  name='StopInstancesMetadata',
  full_name='yandex.cloud.compute.v1.instancegroup.StopInstancesMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.StopInstancesMetadata.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3471,
  serialized_end=3521,
)


_LISTINSTANCEGROUPSREQUEST = _descriptor.Descriptor(
  name='ListInstanceGroupsRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsRequest.view', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3524,
  serialized_end=3738,
)


_LISTINSTANCEGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListInstanceGroupsResponse',
  full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_groups', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsResponse.instance_groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3741,
  serialized_end=3873,
)


_LISTINSTANCEGROUPINSTANCESREQUEST = _descriptor.Descriptor(
  name='ListInstanceGroupInstancesRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesRequest.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3876,
  serialized_end=4042,
)


_LISTINSTANCEGROUPINSTANCESRESPONSE = _descriptor.Descriptor(
  name='ListInstanceGroupInstancesResponse',
  full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instances', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesResponse.instances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4045,
  serialized_end=4181,
)


_DELETEINSTANCESREQUEST = _descriptor.Descriptor(
  name='DeleteInstancesRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.DeleteInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.DeleteInstancesRequest.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='managed_instance_ids', full_name='yandex.cloud.compute.v1.instancegroup.DeleteInstancesRequest.managed_instance_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003>=1\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_another', full_name='yandex.cloud.compute.v1.instancegroup.DeleteInstancesRequest.create_another', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4184,
  serialized_end=4320,
)


_STOPINSTANCESREQUEST = _descriptor.Descriptor(
  name='StopInstancesRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.StopInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.StopInstancesRequest.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='managed_instance_ids', full_name='yandex.cloud.compute.v1.instancegroup.StopInstancesRequest.managed_instance_ids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003>=1\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4322,
  serialized_end=4432,
)


_LISTINSTANCEGROUPOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListInstanceGroupOperationsRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsRequest.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4435,
  serialized_end=4602,
)


_LISTINSTANCEGROUPOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListInstanceGroupOperationsResponse',
  full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4604,
  serialized_end=4721,
)


_LISTINSTANCEGROUPLOGRECORDSREQUEST = _descriptor.Descriptor(
  name='ListInstanceGroupLogRecordsRequest',
  full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_group_id', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsRequest.instance_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4724,
  serialized_end=4883,
)


_LISTINSTANCEGROUPLOGRECORDSRESPONSE = _descriptor.Descriptor(
  name='ListInstanceGroupLogRecordsResponse',
  full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_records', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsResponse.log_records', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4886,
  serialized_end=5019,
)

_GETINSTANCEGROUPREQUEST.fields_by_name['view'].enum_type = _INSTANCEGROUPVIEW
_CREATEINSTANCEGROUPREQUEST_LABELSENTRY.containing_type = _CREATEINSTANCEGROUPREQUEST
_CREATEINSTANCEGROUPREQUEST.fields_by_name['labels'].message_type = _CREATEINSTANCEGROUPREQUEST_LABELSENTRY
_CREATEINSTANCEGROUPREQUEST.fields_by_name['instance_template'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._INSTANCETEMPLATE
_CREATEINSTANCEGROUPREQUEST.fields_by_name['scale_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._SCALEPOLICY
_CREATEINSTANCEGROUPREQUEST.fields_by_name['deploy_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._DEPLOYPOLICY
_CREATEINSTANCEGROUPREQUEST.fields_by_name['allocation_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._ALLOCATIONPOLICY
_CREATEINSTANCEGROUPREQUEST.fields_by_name['load_balancer_spec'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._LOADBALANCERSPEC
_CREATEINSTANCEGROUPREQUEST.fields_by_name['health_checks_spec'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._HEALTHCHECKSSPEC
_CREATEINSTANCEGROUPREQUEST.fields_by_name['variables'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._VARIABLE
_CREATEINSTANCEGROUPREQUEST.fields_by_name['application_load_balancer_spec'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._APPLICATIONLOADBALANCERSPEC
_UPDATEINSTANCEGROUPREQUEST_LABELSENTRY.containing_type = _UPDATEINSTANCEGROUPREQUEST
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['labels'].message_type = _UPDATEINSTANCEGROUPREQUEST_LABELSENTRY
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['instance_template'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._INSTANCETEMPLATE
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['scale_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._SCALEPOLICY
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['deploy_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._DEPLOYPOLICY
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['allocation_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._ALLOCATIONPOLICY
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['health_checks_spec'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._HEALTHCHECKSSPEC
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['load_balancer_spec'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._LOADBALANCERSPEC
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['variables'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._VARIABLE
_LISTINSTANCEGROUPSREQUEST.fields_by_name['view'].enum_type = _INSTANCEGROUPVIEW
_LISTINSTANCEGROUPSRESPONSE.fields_by_name['instance_groups'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._INSTANCEGROUP
_LISTINSTANCEGROUPINSTANCESRESPONSE.fields_by_name['instances'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._MANAGEDINSTANCE
_LISTINSTANCEGROUPOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
_LISTINSTANCEGROUPLOGRECORDSRESPONSE.fields_by_name['log_records'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._LOGRECORD
DESCRIPTOR.message_types_by_name['GetInstanceGroupRequest'] = _GETINSTANCEGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreateInstanceGroupRequest'] = _CREATEINSTANCEGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreateInstanceGroupFromYamlRequest'] = _CREATEINSTANCEGROUPFROMYAMLREQUEST
DESCRIPTOR.message_types_by_name['CreateInstanceGroupMetadata'] = _CREATEINSTANCEGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdateInstanceGroupRequest'] = _UPDATEINSTANCEGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateInstanceGroupFromYamlRequest'] = _UPDATEINSTANCEGROUPFROMYAMLREQUEST
DESCRIPTOR.message_types_by_name['UpdateInstanceGroupMetadata'] = _UPDATEINSTANCEGROUPMETADATA
DESCRIPTOR.message_types_by_name['StartInstanceGroupRequest'] = _STARTINSTANCEGROUPREQUEST
DESCRIPTOR.message_types_by_name['StartInstanceGroupMetadata'] = _STARTINSTANCEGROUPMETADATA
DESCRIPTOR.message_types_by_name['StopInstanceGroupRequest'] = _STOPINSTANCEGROUPREQUEST
DESCRIPTOR.message_types_by_name['StopInstanceGroupMetadata'] = _STOPINSTANCEGROUPMETADATA
DESCRIPTOR.message_types_by_name['DeleteInstanceGroupRequest'] = _DELETEINSTANCEGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteInstanceGroupMetadata'] = _DELETEINSTANCEGROUPMETADATA
DESCRIPTOR.message_types_by_name['DeleteInstancesMetadata'] = _DELETEINSTANCESMETADATA
DESCRIPTOR.message_types_by_name['StopInstancesMetadata'] = _STOPINSTANCESMETADATA
DESCRIPTOR.message_types_by_name['ListInstanceGroupsRequest'] = _LISTINSTANCEGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListInstanceGroupsResponse'] = _LISTINSTANCEGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['ListInstanceGroupInstancesRequest'] = _LISTINSTANCEGROUPINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['ListInstanceGroupInstancesResponse'] = _LISTINSTANCEGROUPINSTANCESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteInstancesRequest'] = _DELETEINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['StopInstancesRequest'] = _STOPINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['ListInstanceGroupOperationsRequest'] = _LISTINSTANCEGROUPOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListInstanceGroupOperationsResponse'] = _LISTINSTANCEGROUPOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['ListInstanceGroupLogRecordsRequest'] = _LISTINSTANCEGROUPLOGRECORDSREQUEST
DESCRIPTOR.message_types_by_name['ListInstanceGroupLogRecordsResponse'] = _LISTINSTANCEGROUPLOGRECORDSRESPONSE
DESCRIPTOR.enum_types_by_name['InstanceGroupView'] = _INSTANCEGROUPVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetInstanceGroupRequest = _reflection.GeneratedProtocolMessageType('GetInstanceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCEGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.GetInstanceGroupRequest)
  })
_sym_db.RegisterMessage(GetInstanceGroupRequest)

CreateInstanceGroupRequest = _reflection.GeneratedProtocolMessageType('CreateInstanceGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEINSTANCEGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEINSTANCEGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest)
  })
_sym_db.RegisterMessage(CreateInstanceGroupRequest)
_sym_db.RegisterMessage(CreateInstanceGroupRequest.LabelsEntry)

CreateInstanceGroupFromYamlRequest = _reflection.GeneratedProtocolMessageType('CreateInstanceGroupFromYamlRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINSTANCEGROUPFROMYAMLREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupFromYamlRequest)
  })
_sym_db.RegisterMessage(CreateInstanceGroupFromYamlRequest)

CreateInstanceGroupMetadata = _reflection.GeneratedProtocolMessageType('CreateInstanceGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINSTANCEGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupMetadata)
  })
_sym_db.RegisterMessage(CreateInstanceGroupMetadata)

UpdateInstanceGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateInstanceGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEINSTANCEGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEINSTANCEGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest)
  })
_sym_db.RegisterMessage(UpdateInstanceGroupRequest)
_sym_db.RegisterMessage(UpdateInstanceGroupRequest.LabelsEntry)

UpdateInstanceGroupFromYamlRequest = _reflection.GeneratedProtocolMessageType('UpdateInstanceGroupFromYamlRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINSTANCEGROUPFROMYAMLREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupFromYamlRequest)
  })
_sym_db.RegisterMessage(UpdateInstanceGroupFromYamlRequest)

UpdateInstanceGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdateInstanceGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINSTANCEGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupMetadata)
  })
_sym_db.RegisterMessage(UpdateInstanceGroupMetadata)

StartInstanceGroupRequest = _reflection.GeneratedProtocolMessageType('StartInstanceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTINSTANCEGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.StartInstanceGroupRequest)
  })
_sym_db.RegisterMessage(StartInstanceGroupRequest)

StartInstanceGroupMetadata = _reflection.GeneratedProtocolMessageType('StartInstanceGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STARTINSTANCEGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.StartInstanceGroupMetadata)
  })
_sym_db.RegisterMessage(StartInstanceGroupMetadata)

StopInstanceGroupRequest = _reflection.GeneratedProtocolMessageType('StopInstanceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPINSTANCEGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.StopInstanceGroupRequest)
  })
_sym_db.RegisterMessage(StopInstanceGroupRequest)

StopInstanceGroupMetadata = _reflection.GeneratedProtocolMessageType('StopInstanceGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STOPINSTANCEGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.StopInstanceGroupMetadata)
  })
_sym_db.RegisterMessage(StopInstanceGroupMetadata)

DeleteInstanceGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteInstanceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEINSTANCEGROUPREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.DeleteInstanceGroupRequest)
  })
_sym_db.RegisterMessage(DeleteInstanceGroupRequest)

DeleteInstanceGroupMetadata = _reflection.GeneratedProtocolMessageType('DeleteInstanceGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEINSTANCEGROUPMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.DeleteInstanceGroupMetadata)
  })
_sym_db.RegisterMessage(DeleteInstanceGroupMetadata)

DeleteInstancesMetadata = _reflection.GeneratedProtocolMessageType('DeleteInstancesMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEINSTANCESMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.DeleteInstancesMetadata)
  })
_sym_db.RegisterMessage(DeleteInstancesMetadata)

StopInstancesMetadata = _reflection.GeneratedProtocolMessageType('StopInstancesMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STOPINSTANCESMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.StopInstancesMetadata)
  })
_sym_db.RegisterMessage(StopInstancesMetadata)

ListInstanceGroupsRequest = _reflection.GeneratedProtocolMessageType('ListInstanceGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCEGROUPSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsRequest)
  })
_sym_db.RegisterMessage(ListInstanceGroupsRequest)

ListInstanceGroupsResponse = _reflection.GeneratedProtocolMessageType('ListInstanceGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCEGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsResponse)
  })
_sym_db.RegisterMessage(ListInstanceGroupsResponse)

ListInstanceGroupInstancesRequest = _reflection.GeneratedProtocolMessageType('ListInstanceGroupInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCEGROUPINSTANCESREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesRequest)
  })
_sym_db.RegisterMessage(ListInstanceGroupInstancesRequest)

ListInstanceGroupInstancesResponse = _reflection.GeneratedProtocolMessageType('ListInstanceGroupInstancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCEGROUPINSTANCESRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesResponse)
  })
_sym_db.RegisterMessage(ListInstanceGroupInstancesResponse)

DeleteInstancesRequest = _reflection.GeneratedProtocolMessageType('DeleteInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEINSTANCESREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.DeleteInstancesRequest)
  })
_sym_db.RegisterMessage(DeleteInstancesRequest)

StopInstancesRequest = _reflection.GeneratedProtocolMessageType('StopInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPINSTANCESREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.StopInstancesRequest)
  })
_sym_db.RegisterMessage(StopInstancesRequest)

ListInstanceGroupOperationsRequest = _reflection.GeneratedProtocolMessageType('ListInstanceGroupOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCEGROUPOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsRequest)
  })
_sym_db.RegisterMessage(ListInstanceGroupOperationsRequest)

ListInstanceGroupOperationsResponse = _reflection.GeneratedProtocolMessageType('ListInstanceGroupOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCEGROUPOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsResponse)
  })
_sym_db.RegisterMessage(ListInstanceGroupOperationsResponse)

ListInstanceGroupLogRecordsRequest = _reflection.GeneratedProtocolMessageType('ListInstanceGroupLogRecordsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCEGROUPLOGRECORDSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsRequest)
  })
_sym_db.RegisterMessage(ListInstanceGroupLogRecordsRequest)

ListInstanceGroupLogRecordsResponse = _reflection.GeneratedProtocolMessageType('ListInstanceGroupLogRecordsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCEGROUPLOGRECORDSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsResponse)
  })
_sym_db.RegisterMessage(ListInstanceGroupLogRecordsResponse)


DESCRIPTOR._options = None
_GETINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._options = None
_CREATEINSTANCEGROUPREQUEST_LABELSENTRY._options = None
_CREATEINSTANCEGROUPREQUEST.fields_by_name['folder_id']._options = None
_CREATEINSTANCEGROUPREQUEST.fields_by_name['name']._options = None
_CREATEINSTANCEGROUPREQUEST.fields_by_name['description']._options = None
_CREATEINSTANCEGROUPREQUEST.fields_by_name['labels']._options = None
_CREATEINSTANCEGROUPREQUEST.fields_by_name['instance_template']._options = None
_CREATEINSTANCEGROUPREQUEST.fields_by_name['scale_policy']._options = None
_CREATEINSTANCEGROUPREQUEST.fields_by_name['deploy_policy']._options = None
_CREATEINSTANCEGROUPREQUEST.fields_by_name['allocation_policy']._options = None
_CREATEINSTANCEGROUPFROMYAMLREQUEST.fields_by_name['folder_id']._options = None
_CREATEINSTANCEGROUPFROMYAMLREQUEST.fields_by_name['instance_group_yaml']._options = None
_CREATEINSTANCEGROUPMETADATA.fields_by_name['instance_group_id']._options = None
_UPDATEINSTANCEGROUPREQUEST_LABELSENTRY._options = None
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._options = None
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['name']._options = None
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['description']._options = None
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['labels']._options = None
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['instance_template']._options = None
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['scale_policy']._options = None
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['deploy_policy']._options = None
_UPDATEINSTANCEGROUPREQUEST.fields_by_name['allocation_policy']._options = None
_UPDATEINSTANCEGROUPFROMYAMLREQUEST.fields_by_name['instance_group_id']._options = None
_UPDATEINSTANCEGROUPFROMYAMLREQUEST.fields_by_name['instance_group_yaml']._options = None
_STARTINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._options = None
_STOPINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._options = None
_DELETEINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._options = None
_LISTINSTANCEGROUPSREQUEST.fields_by_name['folder_id']._options = None
_LISTINSTANCEGROUPSREQUEST.fields_by_name['page_size']._options = None
_LISTINSTANCEGROUPSREQUEST.fields_by_name['page_token']._options = None
_LISTINSTANCEGROUPSREQUEST.fields_by_name['filter']._options = None
_LISTINSTANCEGROUPINSTANCESREQUEST.fields_by_name['instance_group_id']._options = None
_LISTINSTANCEGROUPINSTANCESREQUEST.fields_by_name['page_size']._options = None
_LISTINSTANCEGROUPINSTANCESREQUEST.fields_by_name['page_token']._options = None
_LISTINSTANCEGROUPINSTANCESREQUEST.fields_by_name['filter']._options = None
_DELETEINSTANCESREQUEST.fields_by_name['instance_group_id']._options = None
_DELETEINSTANCESREQUEST.fields_by_name['managed_instance_ids']._options = None
_STOPINSTANCESREQUEST.fields_by_name['instance_group_id']._options = None
_STOPINSTANCESREQUEST.fields_by_name['managed_instance_ids']._options = None
_LISTINSTANCEGROUPOPERATIONSREQUEST.fields_by_name['instance_group_id']._options = None
_LISTINSTANCEGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTINSTANCEGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTINSTANCEGROUPOPERATIONSREQUEST.fields_by_name['filter']._options = None
_LISTINSTANCEGROUPLOGRECORDSREQUEST.fields_by_name['instance_group_id']._options = None
_LISTINSTANCEGROUPLOGRECORDSREQUEST.fields_by_name['page_size']._options = None
_LISTINSTANCEGROUPLOGRECORDSREQUEST.fields_by_name['page_token']._options = None
_LISTINSTANCEGROUPLOGRECORDSREQUEST.fields_by_name['filter']._options = None

_INSTANCEGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='InstanceGroupService',
  full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=5064,
  serialized_end=8687,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.Get',
    index=0,
    containing_service=None,
    input_type=_GETINSTANCEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2._INSTANCEGROUP,
    serialized_options=b'\202\323\344\223\0020\022./compute/v1/instanceGroups/{instance_group_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.List',
    index=1,
    containing_service=None,
    input_type=_LISTINSTANCEGROUPSREQUEST,
    output_type=_LISTINSTANCEGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\022\032/compute/v1/instanceGroups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEINSTANCEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\037\"\032/compute/v1/instanceGroups:\001*\262\322*,\n\033CreateInstanceGroupMetadata\022\rInstanceGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFromYaml',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.CreateFromYaml',
    index=3,
    containing_service=None,
    input_type=_CREATEINSTANCEGROUPFROMYAMLREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002$\"\037/compute/v1/instanceGroups:yaml:\001*\262\322*,\n\033CreateInstanceGroupMetadata\022\rInstanceGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.Update',
    index=4,
    containing_service=None,
    input_type=_UPDATEINSTANCEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\00232./compute/v1/instanceGroups/{instance_group_id}:\001*\262\322*,\n\033UpdateInstanceGroupMetadata\022\rInstanceGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFromYaml',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.UpdateFromYaml',
    index=5,
    containing_service=None,
    input_type=_UPDATEINSTANCEGROUPFROMYAMLREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002823/compute/v1/instanceGroups/{instance_group_id}:yaml:\001*\262\322*,\n\033UpdateInstanceGroupMetadata\022\rInstanceGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Stop',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.Stop',
    index=6,
    containing_service=None,
    input_type=_STOPINSTANCEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0025\"3/compute/v1/instanceGroups/{instance_group_id}:stop\262\322**\n\031StopInstanceGroupMetadata\022\rInstanceGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Start',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.Start',
    index=7,
    containing_service=None,
    input_type=_STARTINSTANCEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0026\"4/compute/v1/instanceGroups/{instance_group_id}:start\262\322*+\n\032StartInstanceGroupMetadata\022\rInstanceGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.Delete',
    index=8,
    containing_service=None,
    input_type=_DELETEINSTANCEGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0020*./compute/v1/instanceGroups/{instance_group_id}\262\322*4\n\033DeleteInstanceGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListInstances',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.ListInstances',
    index=9,
    containing_service=None,
    input_type=_LISTINSTANCEGROUPINSTANCESREQUEST,
    output_type=_LISTINSTANCEGROUPINSTANCESRESPONSE,
    serialized_options=b'\202\323\344\223\002:\0228/compute/v1/instanceGroups/{instance_group_id}/instances',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteInstances',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.DeleteInstances',
    index=10,
    containing_service=None,
    input_type=_DELETEINSTANCESREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*(\n\027DeleteInstancesMetadata\022\rInstanceGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopInstances',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.StopInstances',
    index=11,
    containing_service=None,
    input_type=_STOPINSTANCESREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\262\322*&\n\025StopInstancesMetadata\022\rInstanceGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.ListOperations',
    index=12,
    containing_service=None,
    input_type=_LISTINSTANCEGROUPOPERATIONSREQUEST,
    output_type=_LISTINSTANCEGROUPOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002;\0229/compute/v1/instanceGroups/{instance_group_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLogRecords',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.ListLogRecords',
    index=13,
    containing_service=None,
    input_type=_LISTINSTANCEGROUPLOGRECORDSREQUEST,
    output_type=_LISTINSTANCEGROUPLOGRECORDSRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0223/compute/v1/instanceGroups/{instance_group_id}:logs',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.ListAccessBindings',
    index=14,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002=\022;/compute/v1/instanceGroups/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.SetAccessBindings',
    index=15,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002?\":/compute/v1/instanceGroups/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.compute.v1.instancegroup.InstanceGroupService.UpdateAccessBindings',
    index=16,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002B\"=/compute/v1/instanceGroups/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INSTANCEGROUPSERVICE)

DESCRIPTOR.services_by_name['InstanceGroupService'] = _INSTANCEGROUPSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/validation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/validation.proto',
  package='yandex.cloud',
  syntax='proto3',
  serialized_options=b'\n\020yandex.cloud.apiZ6github.com/yandex-cloud/go-genproto/yandex/cloud;cloud',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dyandex/cloud/validation.proto\x12\x0cyandex.cloud\x1a google/protobuf/descriptor.proto\"<\n\nMapKeySpec\x12\r\n\x05value\x18\x01 \x01(\t\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12\x0e\n\x06length\x18\x03 \x01(\t:4\n\x0b\x65xactly_one\x12\x1d.google.protobuf.OneofOptions\x18\x98\x98\x06 \x01(\x08:1\n\x08required\x12\x1d.google.protobuf.FieldOptions\x18\xfd\x98\x06 \x01(\x08:0\n\x07pattern\x12\x1d.google.protobuf.FieldOptions\x18\xfe\x98\x06 \x01(\t:.\n\x05value\x12\x1d.google.protobuf.FieldOptions\x18\xff\x98\x06 \x01(\t:-\n\x04size\x12\x1d.google.protobuf.FieldOptions\x18\x80\x99\x06 \x01(\t:/\n\x06length\x12\x1d.google.protobuf.FieldOptions\x18\x81\x99\x06 \x01(\t:/\n\x06unique\x12\x1d.google.protobuf.FieldOptions\x18\x82\x99\x06 \x01(\x08:J\n\x07map_key\x12\x1d.google.protobuf.FieldOptions\x18\x86\x99\x06 \x01(\x0b\x32\x18.yandex.cloud.MapKeySpecBJ\n\x10yandex.cloud.apiZ6github.com/yandex-cloud/go-genproto/yandex/cloud;cloudb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


EXACTLY_ONE_FIELD_NUMBER = 101400
exactly_one = _descriptor.FieldDescriptor(
  name='exactly_one', full_name='yandex.cloud.exactly_one', index=0,
  number=101400, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
REQUIRED_FIELD_NUMBER = 101501
required = _descriptor.FieldDescriptor(
  name='required', full_name='yandex.cloud.required', index=1,
  number=101501, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PATTERN_FIELD_NUMBER = 101502
pattern = _descriptor.FieldDescriptor(
  name='pattern', full_name='yandex.cloud.pattern', index=2,
  number=101502, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
VALUE_FIELD_NUMBER = 101503
value = _descriptor.FieldDescriptor(
  name='value', full_name='yandex.cloud.value', index=3,
  number=101503, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
SIZE_FIELD_NUMBER = 101504
size = _descriptor.FieldDescriptor(
  name='size', full_name='yandex.cloud.size', index=4,
  number=101504, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
LENGTH_FIELD_NUMBER = 101505
length = _descriptor.FieldDescriptor(
  name='length', full_name='yandex.cloud.length', index=5,
  number=101505, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNIQUE_FIELD_NUMBER = 101506
unique = _descriptor.FieldDescriptor(
  name='unique', full_name='yandex.cloud.unique', index=6,
  number=101506, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MAP_KEY_FIELD_NUMBER = 101510
map_key = _descriptor.FieldDescriptor(
  name='map_key', full_name='yandex.cloud.map_key', index=7,
  number=101510, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_MAPKEYSPEC = _descriptor.Descriptor(
  name='MapKeySpec',
  full_name='yandex.cloud.MapKeySpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.MapKeySpec.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='yandex.cloud.MapKeySpec.pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='yandex.cloud.MapKeySpec.length', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=141,
)

DESCRIPTOR.message_types_by_name['MapKeySpec'] = _MAPKEYSPEC
DESCRIPTOR.extensions_by_name['exactly_one'] = exactly_one
DESCRIPTOR.extensions_by_name['required'] = required
DESCRIPTOR.extensions_by_name['pattern'] = pattern
DESCRIPTOR.extensions_by_name['value'] = value
DESCRIPTOR.extensions_by_name['size'] = size
DESCRIPTOR.extensions_by_name['length'] = length
DESCRIPTOR.extensions_by_name['unique'] = unique
DESCRIPTOR.extensions_by_name['map_key'] = map_key
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MapKeySpec = _reflection.GeneratedProtocolMessageType('MapKeySpec', (_message.Message,), {
  'DESCRIPTOR' : _MAPKEYSPEC,
  '__module__' : 'yandex.cloud.validation_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.MapKeySpec)
  })
_sym_db.RegisterMessage(MapKeySpec)

google_dot_protobuf_dot_descriptor__pb2.OneofOptions.RegisterExtension(exactly_one)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(required)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(pattern)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(value)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(size)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(length)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(unique)
map_key.message_type = _MAPKEYSPEC
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(map_key)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/vision/v1/image_copy_search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/vision/v1/image_copy_search.proto',
  package='yandex.cloud.ai.vision.v1',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;vision',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/ai/vision/v1/image_copy_search.proto\x12\x19yandex.cloud.ai.vision.v1\"j\n\x19ImageCopySearchAnnotation\x12\x12\n\ncopy_count\x18\x01 \x01(\x03\x12\x39\n\x0btop_results\x18\x02 \x03(\x0b\x32$.yandex.cloud.ai.vision.v1.CopyMatch\"T\n\tCopyMatch\x12\x11\n\timage_url\x18\x01 \x01(\t\x12\x10\n\x08page_url\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\tBe\n\x1dyandex.cloud.api.ai.vision.v1ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v1;visionb\x06proto3'
)




_IMAGECOPYSEARCHANNOTATION = _descriptor.Descriptor(
  name='ImageCopySearchAnnotation',
  full_name='yandex.cloud.ai.vision.v1.ImageCopySearchAnnotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='copy_count', full_name='yandex.cloud.ai.vision.v1.ImageCopySearchAnnotation.copy_count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='top_results', full_name='yandex.cloud.ai.vision.v1.ImageCopySearchAnnotation.top_results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=186,
)


_COPYMATCH = _descriptor.Descriptor(
  name='CopyMatch',
  full_name='yandex.cloud.ai.vision.v1.CopyMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_url', full_name='yandex.cloud.ai.vision.v1.CopyMatch.image_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_url', full_name='yandex.cloud.ai.vision.v1.CopyMatch.page_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='yandex.cloud.ai.vision.v1.CopyMatch.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.ai.vision.v1.CopyMatch.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=272,
)

_IMAGECOPYSEARCHANNOTATION.fields_by_name['top_results'].message_type = _COPYMATCH
DESCRIPTOR.message_types_by_name['ImageCopySearchAnnotation'] = _IMAGECOPYSEARCHANNOTATION
DESCRIPTOR.message_types_by_name['CopyMatch'] = _COPYMATCH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ImageCopySearchAnnotation = _reflection.GeneratedProtocolMessageType('ImageCopySearchAnnotation', (_message.Message,), {
  'DESCRIPTOR' : _IMAGECOPYSEARCHANNOTATION,
  '__module__' : 'yandex.cloud.ai.vision.v1.image_copy_search_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v1.ImageCopySearchAnnotation)
  })
_sym_db.RegisterMessage(ImageCopySearchAnnotation)

CopyMatch = _reflection.GeneratedProtocolMessageType('CopyMatch', (_message.Message,), {
  'DESCRIPTOR' : _COPYMATCH,
  '__module__' : 'yandex.cloud.ai.vision.v1.image_copy_search_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v1.CopyMatch)
  })
_sym_db.RegisterMessage(CopyMatch)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
